@@ -4,12 +4,12 @@
 #' @importFrom graphics axis box text mtext par image
 #' @importFrom grDevices colorRampPalette dev.off grey
 #' @importFrom tikzDevice tikz
-#' @importFrom fields image.plot
 #' @name plotEstimator
 #' @param object an object of class "BayesSUR"
 #' @param estimator print the heatmap of estimators. Default "all" is to print all estimators. The value "beta" is for the estimated coefficients matrix, "gamma" for the latent indicator matrix and "Gy" for the graph of responses
 #' @param colorScale.gamma value palette for gamma
 #' @param colorScale.beta a vector of three colors for diverging color schemes
+#' @param legend.cex.axis magnification of axis annotation relative to cex
 #' @param name.responses a vector of the response names. The default is "NA" only to show the locations. The value "auto" show the response names from the orginal data. 
 #' @param name.predictors a vector of the predictor names. The default is "NA" only to show the locations. The value "auto" show the predictor names from the orginal data.
 #' @param xlab a title for the x axis
@@ -18,6 +18,7 @@
 #' @param output the file name of printed figure
 #' @param header the main title
 #' @param header.cex size of the main title
+#' @param mgp the margin line (in mex units) for the axis title, axis labels and axis line
 #' @param ... other arguments
 #' 
 #' @examples
@@ -40,8 +41,8 @@
 #' }
 #' 
 #' @export
-plotEstimator <- function(object, estimator="all", colorScale.gamma=grey((100:0)/100), colorScale.beta=c("blue","white","red"), 
-                          name.responses=NA, name.predictors=NA, xlab="", ylab="", fig.tex=FALSE, output="ParamEstimator", header="", header.cex=2, ...){
+plotEstimator <- function(object, estimator="all", colorScale.gamma=grey((100:0)/100), colorScale.beta=c("blue","white","red"), legend.cex.axis=1,
+                          name.responses=NA, name.predictors=NA, xlab="", ylab="", fig.tex=FALSE, output="ParamEstimator", header="", header.cex=2, mgp=c(2.5,1,0), ...){
   
   object$output[-1] <- paste(object$output$outFilePath,object$output[-1],sep="")
   beta_hat <- as.matrix( read.table(object$output$beta) )
@@ -68,7 +69,7 @@ plotEstimator <- function(object, estimator="all", colorScale.gamma=grey((100:0)
   on.exit(par(opar))    
   if(!fig.tex){
     
-    par(mar=c(6,3,5,2.5))
+    par(mar=c(6,6,5.1,2.6))
     if(estimator[1]=="all"){
       par(mfrow=c(1,ifelse(toupper(object$input$covariancePrior)=="HIW",3,2)))
     }
@@ -80,8 +81,9 @@ plotEstimator <- function(object, estimator="all", colorScale.gamma=grey((100:0)
       # floor(100*constant)+100-1 colours that your want in the legend bar which has the white middle colour
       colorbar <- c(colorRampPalette(c(colorScale.beta[1], colorScale.beta[2]))(floor(1000/(-(max(beta_hat)-min(beta_hat))/min(beta_hat)-1))), colorRampPalette(c(colorScale.beta[2],colorScale.beta[3]))(1000)[-1])
       
-      image.plot(z=beta_hat, x=1:nrow(beta_hat), y=1:ncol(beta_hat), col=colorbar, axes=ifelse(is.na(name.responses)[1],TRUE,FALSE), xlab=xlab, ylab=ylab,main=expression(hat(bold(B))),cex.main=1.5,cex.lab=1.5,...);box()
-      #vertical.image.legend(col=colorbar, zlim=c(min(beta_hat),max(beta_hat)), legend.cex.axis=legend.cex.axis)
+      image(z=beta_hat, x=1:nrow(beta_hat), y=1:ncol(beta_hat), col=colorbar, mgp=mgp,  
+            axes=ifelse(is.na(name.responses)[1],TRUE,FALSE), xlab=xlab, ylab=ylab,main=expression(hat(bold(B))),cex.main=1.5,cex.lab=1.5,...);box()
+      vertical.image.legend(col=colorbar, zlim=c(min(beta_hat),max(beta_hat)), legend.cex.axis=legend.cex.axis)
       if(!is.na(name.responses)[1]){
         par(las=2, cex.axis=1)
         axis(2, at = 1:ncol(beta_hat), labels=name.responses)
@@ -90,8 +92,9 @@ plotEstimator <- function(object, estimator="all", colorScale.gamma=grey((100:0)
       }
     }
     if(sum(estimator %in% c("all","beta"))){
-      image.plot(z=gamma_hat, x=1:nrow(gamma_hat), y=1:ncol(gamma_hat), col=colorScale.gamma, axes=ifelse(is.na(name.responses)[1],TRUE,FALSE), xlab=xlab, ylab=ylab,main=expression(hat(bold(Gamma))),cex.main=1.5,cex.lab=1.5,...);box()
-      #vertical.image.legend(col=colorScale.gamma, zlim=c(0,1), legend.cex.axis=legend.cex.axis)
+      image(z=gamma_hat, x=1:nrow(gamma_hat), y=1:ncol(gamma_hat), col=colorScale.gamma, mgp=mgp, 
+            axes=ifelse(is.na(name.responses)[1],TRUE,FALSE), xlab=xlab, ylab=ylab,main=expression(hat(bold(Gamma))),cex.main=1.5,cex.lab=1.5,...);box()
+      vertical.image.legend(col=colorScale.gamma, zlim=c(0,1), legend.cex.axis=legend.cex.axis)
       if(!is.na(name.responses)[1]){
         par(las=2, cex.axis=1)
         axis(2, at = 1:ncol(gamma_hat), labels=name.responses)
@@ -104,9 +107,9 @@ plotEstimator <- function(object, estimator="all", colorScale.gamma=grey((100:0)
       if(sum(estimator %in% c("all","Gy"))){
         Gy_hat <- as.matrix( read.table(object$output$G) )
         
-        image.plot(z=Gy_hat+diag(ncol(Gy_hat)), x=1:nrow(Gy_hat), y=1:nrow(Gy_hat), col=colorScale.gamma, 
-              axes=ifelse(is.na(name.responses)[1],TRUE,FALSE), xlab=xlab, ylab=ylab,main="Estimated graph of responses",cex.main=1.5,cex.lab=1.5);box()
-        #vertical.image.legend(col=colorScale.gamma, zlim=c(min(Gy_hat),max(Gy_hat)), legend.cex.axis=legend.cex.axis)
+        image(z=Gy_hat+diag(ncol(Gy_hat)), x=1:nrow(Gy_hat), y=1:nrow(Gy_hat), col=colorScale.gamma, mgp=mgp, 
+              axes=ifelse(is.na(name.responses)[1],TRUE,FALSE), xlab=xlab, ylab=ylab,main="Estimated graph of responses",cex.main=1.5,cex.lab=1.5,...);box()
+        vertical.image.legend(col=colorScale.gamma, zlim=c(min(Gy_hat),max(Gy_hat)), legend.cex.axis=legend.cex.axis)
         if(!is.na(name.responses)[1]){
           par(las=2, cex.axis=1)
           axis(2, at = 1:ncol(Gy_hat), labels=name.responses)
@@ -118,14 +121,14 @@ plotEstimator <- function(object, estimator="all", colorScale.gamma=grey((100:0)
     title(paste("\n",header,sep=""), cex.main=header.cex, outer=T)
     
   }else{
-    par(mar=c(6,5,5,4))
+    #par(mar=c(6,5,5,4))
     options(tikzMetricPackages = c("\\usepackage{amsmath}","\\usepackage{bm}","\\usetikzlibrary{calc}"))
     if(estimator[1]=="all"){
-      tikz(paste(output,".tex",sep=""),width=7,height=2.3,standAlone=TRUE,packages=c("\\usepackage{tikz}","\\usepackage{amsmath}",
+      tikz(paste(output,".tex",sep=""),width=6.5,height=2.3,standAlone=TRUE,packages=c("\\usepackage{tikz}","\\usepackage{amsmath}",
             "\\usepackage{bm}","\\usepackage[active,tightpage,psfixbb]{preview}","\\PreviewEnvironment{pgfpicture}"))
       par(mfrow=c(1,ifelse(toupper(object$input$covariancePrior)=="HIW",3,2)))
     }else{
-      tikz(paste(output,".tex",sep=""),width=4*length(estimator),height=4,standAlone=TRUE,packages=c("\\usepackage{tikz}","\\usepackage{amsmath}",
+      tikz(paste(output,".tex",sep=""),width=3.5*length(estimator),height=4,standAlone=TRUE,packages=c("\\usepackage{tikz}","\\usepackage{amsmath}",
             "\\usepackage{bm}","\\usepackage[active,tightpage,psfixbb]{preview}","\\PreviewEnvironment{pgfpicture}"))
       if(length(estimator)>1){
         par(mfrow=c(1,length(estimator)))
@@ -136,8 +139,9 @@ plotEstimator <- function(object, estimator="all", colorScale.gamma=grey((100:0)
       # floor(100*constant)+100-1 colours that your want in the legend bar which has the white middle colour
       colorbar <- c(colorRampPalette(c(colorScale.beta[1], colorScale.beta[2]))(floor(1000/(-(max(beta_hat)-min(beta_hat))/min(beta_hat)-1))), colorRampPalette(c(colorScale.beta[2],colorScale.beta[3]))(1000)[-1])
       
-      image.plot(z=beta_hat, x=1:nrow(beta_hat), y=1:ncol(beta_hat), col=colorbar, axes=ifelse(is.na(name.responses)[1],TRUE,FALSE), xlab=xlab, ylab=ylab, main=paste("Estimator","$\\hat{\\bm{B}}$"),cex.main=1.5,cex.lab=1.5);box()
-      #vertical.image.legend(col=colorbar, zlim=c(min(beta_hat),max(beta_hat)), legend.cex.axis=legend.cex.axis)
+      image(z=beta_hat, x=1:nrow(beta_hat), y=1:ncol(beta_hat), col=colorbar, axes=ifelse(is.na(name.responses)[1],TRUE,FALSE), mgp=mgp,  
+            xlab=xlab, ylab=ylab, main=paste("Estimator","$\\hat{\\bm{B}}$"),cex.main=1.5,cex.lab=1.5,...);box()
+      vertical.image.legend(col=colorbar, zlim=c(min(beta_hat),max(beta_hat)), legend.cex.axis=legend.cex.axis)
       if(!is.na(name.responses)[1]){
         par(las=2, cex.axis=1)
         axis(2, at = 1:ncol(beta_hat), labels=name.responses)
@@ -146,8 +150,9 @@ plotEstimator <- function(object, estimator="all", colorScale.gamma=grey((100:0)
       }
     }
     if(sum(estimator %in% c("all","gamma"))){
-      image.plot(z=gamma_hat, x=1:nrow(gamma_hat), y=1:ncol(gamma_hat), col=colorScale.gamma, axes=ifelse(is.na(name.responses)[1],TRUE,FALSE), xlab=xlab, ylab=ylab, main=paste("Estimator","$\\hat{\\mathbf{\\Gamma}}$"),cex.main=1.5,cex.lab=1.5);box()
-      #vertical.image.legend(col=colorScale.gamma, zlim=c(0,1), legend.cex.axis=legend.cex.axis)
+      image(z=gamma_hat, x=1:nrow(gamma_hat), y=1:ncol(gamma_hat), col=colorScale.gamma, axes=ifelse(is.na(name.responses)[1],TRUE,FALSE), mgp=mgp,  
+            xlab=xlab, ylab=ylab, main=paste("Estimator","$\\hat{\\mathbf{\\Gamma}}$"),cex.main=1.5,cex.lab=1.5,...);box()
+      vertical.image.legend(col=colorScale.gamma, zlim=c(0,1), legend.cex.axis=legend.cex.axis)
       if(!is.na(name.responses)[1]){
         par(las=2, cex.axis=1)
         axis(2, at = 1:ncol(gamma_hat), labels=name.responses)
@@ -160,9 +165,9 @@ plotEstimator <- function(object, estimator="all", colorScale.gamma=grey((100:0)
       if(sum(estimator %in% c("all","Gy"))){
         Gy_hat <- as.matrix( read.table(object$output$G) )
         
-        image.plot(z=Gy_hat+diag(ncol(Gy_hat)), x=1:nrow(Gy_hat), y=1:nrow(Gy_hat), col=colorScale.gamma, 
-              axes=ifelse(is.na(name.responses)[1],TRUE,FALSE), xlab=xlab, ylab=ylab, main=paste("Estimator","$\\hat{\\mathcal{G}}$"),cex.main=1.5,cex.lab=1.5);box()
-        #vertical.image.legend(col=colorScale.gamma, zlim=c(min(Gy_hat),max(Gy_hat)), legend.cex.axis=legend.cex.axis)
+        image(z=Gy_hat+diag(ncol(Gy_hat)), x=1:nrow(Gy_hat), y=1:nrow(Gy_hat), col=colorScale.gamma, axes=ifelse(is.na(name.responses)[1],TRUE,FALSE), mgp=mgp, 
+              xlab=xlab, ylab=ylab, main=paste("Estimator","$\\hat{\\mathcal{G}}$"),cex.main=1.5,cex.lab=1.5,...);box()
+        vertical.image.legend(col=colorScale.gamma, zlim=c(min(Gy_hat),max(Gy_hat)), legend.cex.axis=legend.cex.axis)
         
         if(!is.na(name.responses)[1]){
           par(las=2, cex.axis=1)
@@ -178,3 +183,27 @@ plotEstimator <- function(object, estimator="all", colorScale.gamma=grey((100:0)
   }
 
 }
+# the function vertical.image.legend is orginally from the R package "aqfig"
+vertical.image.legend <- function (zlim, col, legend.cex.axis=1) 
+{
+  starting.par.settings <- par(no.readonly = TRUE)
+  #on.exit(par(starting.par.settings))
+  mai <- par("mai")
+  fin <- par("fin")
+  x.legend.fig <- c(1 - (mai[4]/fin[1]), 1)
+  y.legend.fig <- c(mai[1]/fin[2], 1 - (mai[3]/fin[2]))
+  x.legend.plt <- c(x.legend.fig[1] + (0.18 * (x.legend.fig[2] - 
+                                                 x.legend.fig[1])), x.legend.fig[2] - (0.6 * (x.legend.fig[2] - 
+                                                                                                x.legend.fig[1])))
+  y.legend.plt <- y.legend.fig
+  cut.pts <- seq(zlim[1], zlim[2], length = length(col) + 1)
+  z <- (cut.pts[1:length(col)] + cut.pts[2:(length(col) + 1)])/2
+  par(new = TRUE, pty = "m", plt = c(x.legend.plt, y.legend.plt))
+  image(x = 1.5, y = z, z = matrix(z, nrow = 1, ncol = length(col)), 
+        col = col, xlab = "", ylab = "", xaxt = "n", yaxt = "n")
+  axis(4, mgp = c(3, 0.2, 0), las = 2, cex.axis = legend.cex.axis, tcl = -0.1)
+  box()
+  mfg.settings <- par()$mfg
+  par(starting.par.settings)
+  par(mfg = mfg.settings, new = FALSE)
+}
